@@ -172,6 +172,15 @@ int abs_bremse_33_unpack(
     return (0);
 }
 
+int abs_bremse_33_init(struct abs_bremse_33_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_33_t));
+
+    return 0;
+}
+
 uint16_t abs_bremse_33_whlspeed_fl_encode(double value)
 {
     return (uint16_t)(value / 0.015625);
@@ -263,6 +272,15 @@ int abs_bremse_10_unpack(
     return (0);
 }
 
+int abs_bremse_10_init(struct abs_bremse_10_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_10_t));
+
+    return 0;
+}
+
 int abs_bremse_11_pack(
     uint8_t *dst_p,
     const struct abs_bremse_11_t *src_p,
@@ -294,6 +312,15 @@ int abs_bremse_11_unpack(
     return (0);
 }
 
+int abs_bremse_11_init(struct abs_bremse_11_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_11_t));
+
+    return 0;
+}
+
 int abs_bremse_12_pack(
     uint8_t *dst_p,
     const struct abs_bremse_12_t *src_p,
@@ -325,6 +352,15 @@ int abs_bremse_12_unpack(
     return (0);
 }
 
+int abs_bremse_12_init(struct abs_bremse_12_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_12_t));
+
+    return 0;
+}
+
 int abs_bremse_13_pack(
     uint8_t *dst_p,
     const struct abs_bremse_13_t *src_p,
@@ -356,6 +392,15 @@ int abs_bremse_13_unpack(
     return (0);
 }
 
+int abs_bremse_13_init(struct abs_bremse_13_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_13_t));
+
+    return 0;
+}
+
 int abs_drs_rx_id0_pack(
     uint8_t *dst_p,
     const struct abs_drs_rx_id0_t *src_p,
@@ -387,6 +432,15 @@ int abs_drs_rx_id0_unpack(
     return (0);
 }
 
+int abs_drs_rx_id0_init(struct abs_drs_rx_id0_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_drs_rx_id0_t));
+
+    return 0;
+}
+
 int abs_mm5_10_tx1_pack(
     uint8_t *dst_p,
     const struct abs_mm5_10_tx1_t *src_p,
@@ -423,6 +477,15 @@ int abs_mm5_10_tx1_unpack(
     return (0);
 }
 
+int abs_mm5_10_tx1_init(struct abs_mm5_10_tx1_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_mm5_10_tx1_t));
+
+    return 0;
+}
+
 uint16_t abs_mm5_10_tx1_yaw_rate_encode(double value)
 {
     return (uint16_t)((value - -163.84) / 0.005);
@@ -489,6 +552,15 @@ int abs_mm5_10_tx2_unpack(
     return (0);
 }
 
+int abs_mm5_10_tx2_init(struct abs_mm5_10_tx2_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_mm5_10_tx2_t));
+
+    return 0;
+}
+
 uint16_t abs_mm5_10_tx2_roll_rate_encode(double value)
 {
     return (uint16_t)((value - -163.84) / 0.005);
@@ -553,6 +625,15 @@ int abs_mm5_10_tx3_unpack(
     return (0);
 }
 
+int abs_mm5_10_tx3_init(struct abs_mm5_10_tx3_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_mm5_10_tx3_t));
+
+    return 0;
+}
+
 uint16_t abs_mm5_10_tx3_az_encode(double value)
 {
     return (uint16_t)((value - -4.1768) / 0.000127465);
@@ -612,6 +693,15 @@ int abs_bremse_2_unpack(
     return (0);
 }
 
+int abs_bremse_2_init(struct abs_bremse_2_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_2_t));
+
+    return 0;
+}
+
 uint16_t abs_bremse_2_whlspeed_fl_bremse2_encode(double value)
 {
     return (uint16_t)(value / 0.015625);
@@ -702,6 +792,15 @@ int abs_abs_switch_unpack(
     return (0);
 }
 
+int abs_abs_switch_init(struct abs_abs_switch_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_abs_switch_t));
+
+    return 0;
+}
+
 uint8_t abs_abs_switch_abs_switchposition_encode(double value)
 {
     return (uint8_t)(value);
@@ -748,6 +847,15 @@ int abs_bremse_30_unpack(
     return (0);
 }
 
+int abs_bremse_30_init(struct abs_bremse_30_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_30_t));
+
+    return 0;
+}
+
 int abs_bremse_31_pack(
     uint8_t *dst_p,
     const struct abs_bremse_31_t *src_p,
@@ -780,6 +888,15 @@ int abs_bremse_31_unpack(
     return (0);
 }
 
+int abs_bremse_31_init(struct abs_bremse_31_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_31_t));
+
+    return 0;
+}
+
 uint16_t abs_bremse_31_idle_time_encode(double value)
 {
     return (uint16_t)(value);
@@ -837,6 +954,15 @@ int abs_bremse_32_unpack(
     return (0);
 }
 
+int abs_bremse_32_init(struct abs_bremse_32_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_32_t));
+
+    return 0;
+}
+
 uint8_t abs_bremse_32_acc_fa_encode(double value)
 {
     return (uint8_t)(value / 0.05);
@@ -971,6 +1097,15 @@ int abs_bremse_51_unpack(
     return (0);
 }
 
+int abs_bremse_51_init(struct abs_bremse_51_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_51_t));
+
+    return 0;
+}
+
 uint16_t abs_bremse_51_ax1_abs_int_encode(double value)
 {
     return (uint16_t)((value - -4.1768) / 0.00012742);
@@ -1216,6 +1351,15 @@ int abs_bremse_52_unpack(
     return (0);
 }
 
+int abs_bremse_52_init(struct abs_bremse_52_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_52_t));
+
+    return 0;
+}
+
 uint8_t abs_bremse_52_mplx_sw_info_encode(double value)
 {
     return (uint8_t)(value);
@@ -1899,6 +2043,15 @@ int abs_bremse_50_unpack(
     return (0);
 }
 
+int abs_bremse_50_init(struct abs_bremse_50_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_50_t));
+
+    return 0;
+}
+
 uint16_t abs_bremse_50_brake_bal_at50_encode(double value)
 {
     return (uint16_t)(value / 0.1);
@@ -2041,6 +2194,15 @@ int abs_bremse_53_unpack(
     return (0);
 }
 
+int abs_bremse_53_init(struct abs_bremse_53_t *msg_p)
+{
+    if (msg_p == NULL) return -1;
+
+    memset(msg_p, 0, sizeof(struct abs_bremse_53_t));
+
+    return 0;
+}
+
 uint8_t abs_bremse_53_switch_position_encode(double value)
 {
     return (uint8_t)(value);
@@ -2068,7 +2230,7 @@ double abs_bremse_53_p_fa_decode(int16_t value)
 
 bool abs_bremse_53_p_fa_is_in_range(int16_t value)
 {
-    return ((value >= -2785) && (value <= 27850));
+    return ((value >= -2785) && (value <= 27851));
 }
 
 uint8_t abs_bremse_53_bls_encode(double value)
@@ -2338,5 +2500,5 @@ double abs_bremse_53_p_ra_decode(int16_t value)
 
 bool abs_bremse_53_p_ra_is_in_range(int16_t value)
 {
-    return ((value >= -2785) && (value <= 27850));
+    return ((value >= -2785) && (value <= 27851));
 }
