@@ -1,15 +1,13 @@
-import sys
+import functools
 import os
 import re
-import shutil
-import unittest
+import sys
+import tempfile
 import types
-import functools
-
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
+import unittest
+import warnings
+from pathlib import Path
+from unittest.mock import patch
 
 try:
     from StringIO import StringIO
@@ -17,6 +15,7 @@ except ImportError:
     from io import StringIO
 
 import cantools
+import cantools.database
 
 
 def with_fake_screen_width(screen_width):
@@ -53,7 +52,7 @@ def remove_date_time(string):
 
 
 def read_file(filename):
-    with open(filename, 'r') as fin:
+    with open(filename) as fin:
         return remove_date_time(fin.read())
 
 
@@ -62,12 +61,11 @@ def read_utf8_file(filename):
 
     """
 
-    with open(filename, 'r', encoding='utf-8') as fin:
+    with open(filename, encoding='utf-8') as fin:
         return remove_date_time(fin.read())
 
 
 class CanToolsCommandLineTest(unittest.TestCase):
-
     maxDiff = None
 
     def assert_files_equal(self, actual, expected):
@@ -95,10 +93,7 @@ SENSOR_SONARS(
     SENSOR_SONARS_right: 0.0,
     SENSOR_SONARS_rear: 0.0
 )
-  vcan0  064   [10]  F0 01 FF FF FF FF FF FF FF FF ::
-DRIVER_HEARTBEAT(
-    DRIVER_HEARTBEAT_cmd: 240
-)
+  vcan0  064   [10]  F0 01 FF FF FF FF FF FF FF FF :: Wrong data size: 10 instead of 1 bytes
   vcan0  ERROR
 
   vcan0  1F4   [4]  01 02 03 04 ::
@@ -144,10 +139,7 @@ SENSOR_SONARS(
     SENSOR_SONARS_right: 0.0,
     SENSOR_SONARS_rear: 0.0
 )
- (2020-12-19 12:04:48.597222)  vcan0  064   [8]  F0 01 FF FF FF FF FF FF ::
-DRIVER_HEARTBEAT(
-    DRIVER_HEARTBEAT_cmd: 240
-)
+ (2020-12-19 12:04:48.597222)  vcan0  064   [8]  F0 01 FF FF FF FF FF FF :: Wrong data size: 8 instead of 1 bytes
  (2020-12-19 12:04:56.805087)  vcan0  1F4   [4]  01 02 03 04 ::
 IO_DEBUG(
     IO_DEBUG_test_unsigned: 1,
@@ -191,10 +183,7 @@ SENSOR_SONARS(
     SENSOR_SONARS_right: 0.0,
     SENSOR_SONARS_rear: 0.0
 )
- (002.047817)  vcan0  064   [8]  F0 01 FF FF FF FF FF FF ::
-DRIVER_HEARTBEAT(
-    DRIVER_HEARTBEAT_cmd: 240
-)
+ (002.047817)  vcan0  064   [8]  F0 01 FF FF FF FF FF FF :: Wrong data size: 8 instead of 1 bytes
  (012.831664)  vcan0  1F4   [4]  01 02 03 04 ::
 IO_DEBUG(
     IO_DEBUG_test_unsigned: 1,
@@ -246,6 +235,8 @@ CanFd(
         ]
         input_data = """\
 (1594172461.968006) vcan0 0C8#F000000000000000
+(1594172462.968006) vcan0 0C8#F000000000000000 T
+(1594172463.968006) vcan0 0C8#F000000000000000 R
 (1594172462.126542) vcan0 064#F001FFFFFFFFFFFFFFFF
 (1594172462.127684) vcan0 ERROR
 
@@ -263,10 +254,25 @@ SENSOR_SONARS(
     SENSOR_SONARS_right: 0.0,
     SENSOR_SONARS_rear: 0.0
 )
-(1594172462.126542) vcan0 064#F001FFFFFFFFFFFFFFFF ::
-DRIVER_HEARTBEAT(
-    DRIVER_HEARTBEAT_cmd: 240
+(1594172462.968006) vcan0 0C8#F000000000000000 T ::
+SENSOR_SONARS(
+    SENSOR_SONARS_mux: 0,
+    SENSOR_SONARS_err_count: 15,
+    SENSOR_SONARS_left: 0.0,
+    SENSOR_SONARS_middle: 0.0,
+    SENSOR_SONARS_right: 0.0,
+    SENSOR_SONARS_rear: 0.0
 )
+(1594172463.968006) vcan0 0C8#F000000000000000 R ::
+SENSOR_SONARS(
+    SENSOR_SONARS_mux: 0,
+    SENSOR_SONARS_err_count: 15,
+    SENSOR_SONARS_left: 0.0,
+    SENSOR_SONARS_middle: 0.0,
+    SENSOR_SONARS_right: 0.0,
+    SENSOR_SONARS_rear: 0.0
+)
+(1594172462.126542) vcan0 064#F001FFFFFFFFFFFFFFFF :: Wrong data size: 10 instead of 1 bytes
 (1594172462.127684) vcan0 ERROR
 
 (1594172462.356874) vcan0 1F4#01020304 ::
@@ -308,7 +314,7 @@ IO_DEBUG(
 
         expected_output = """\
   vcan0  0C8   [8]  F0 00 00 00 00 00 00 00 :: SENSOR_SONARS(SENSOR_SONARS_mux: 0, SENSOR_SONARS_err_count: 15, SENSOR_SONARS_left: 0.0, SENSOR_SONARS_middle: 0.0, SENSOR_SONARS_right: 0.0, SENSOR_SONARS_rear: 0.0)
-  vcan0  064   [10]  F0 01 FF FF FF FF FF FF FF FF :: DRIVER_HEARTBEAT(DRIVER_HEARTBEAT_cmd: 240)
+  vcan0  064   [10]  F0 01 FF FF FF FF FF FF FF FF :: Wrong data size: 10 instead of 1 bytes
   vcan0  ERROR
 
   vcan0  1F4   [4]  01 02 03 04 :: IO_DEBUG(IO_DEBUG_test_unsigned: 1, IO_DEBUG_test_enum: two, IO_DEBUG_test_signed: 3, IO_DEBUG_test_float: 2.0)
@@ -344,7 +350,7 @@ IO_DEBUG(
 
         expected_output = """\
 (1594172461.968006) vcan0 0C8#F000000000000000 :: SENSOR_SONARS(SENSOR_SONARS_mux: 0, SENSOR_SONARS_err_count: 15, SENSOR_SONARS_left: 0.0, SENSOR_SONARS_middle: 0.0, SENSOR_SONARS_right: 0.0, SENSOR_SONARS_rear: 0.0)
-(1594172462.126542) vcan0 064#F001FFFFFFFFFFFFFFFF :: DRIVER_HEARTBEAT(DRIVER_HEARTBEAT_cmd: 240)
+(1594172462.126542) vcan0 064#F001FFFFFFFFFFFFFFFF :: Wrong data size: 10 instead of 1 bytes
 (1594172462.127684) vcan0 ERROR
 
 (1594172462.356874) vcan0 1F4#01020304 :: IO_DEBUG(IO_DEBUG_test_unsigned: 1, IO_DEBUG_test_enum: two, IO_DEBUG_test_signed: 3, IO_DEBUG_test_float: 2.0)
@@ -1202,41 +1208,38 @@ BATTERY_VT(
                 self.assertEqual(actual_output, expected_output)
 
     def test_convert(self):
-        # DBC to KCD.
-        argv = [
-            'cantools',
-            'convert',
-            'tests/files/dbc/motohawk.dbc',
-            'test_command_line_convert.kcd'
-        ]
+        with tempfile.TemporaryDirectory() as tmpdir:
+            # DBC to KCD.
+            kcd_out_path = os.path.join(tmpdir, 'test_command_line_convert.kcd')
+            argv = [
+                'cantools',
+                'convert',
+                'tests/files/dbc/motohawk.dbc',
+                kcd_out_path
+            ]
 
-        if os.path.exists('test_command_line_convert.kcd'):
-            os.remove('test_command_line_convert.kcd')
+            with patch('sys.argv', argv):
+                cantools._main()
 
-        with patch('sys.argv', argv):
-            cantools._main()
+            db = cantools.database.Database()
+            db.add_kcd_file(kcd_out_path)
+            self.assertEqual(db.version, '1.0')
 
-        db = cantools.database.Database()
-        db.add_kcd_file('test_command_line_convert.kcd')
-        self.assertEqual(db.version, '1.0')
+            # KCD to DBC.
+            dbc_out_path = os.path.join(tmpdir, 'test_command_line_convert.dbc')
+            argv = [
+                'cantools',
+                'convert',
+                kcd_out_path,
+                dbc_out_path
+            ]
 
-        # KCD to DBC.
-        argv = [
-            'cantools',
-            'convert',
-            'test_command_line_convert.kcd',
-            'test_command_line_convert.dbc'
-        ]
+            with patch('sys.argv', argv):
+                cantools._main()
 
-        if os.path.exists('test_command_line_convert.dbc'):
-            os.remove('test_command_line_convert.dbc')
-
-        with patch('sys.argv', argv):
-            cantools._main()
-
-        db = cantools.database.Database()
-        db.add_dbc_file('test_command_line_convert.dbc')
-        self.assertEqual(db.version, '1.0')
+            db = cantools.database.Database()
+            db.add_dbc_file(dbc_out_path)
+            self.assertEqual(db.version, '1.0')
 
     def test_convert_bad_outfile(self):
         argv = [
@@ -1259,6 +1262,7 @@ BATTERY_VT(
             'motohawk',
             'padding_bit_order',
             'vehicle',
+            'open_actuator',
             'floating_point',
             'floating_point_use_float',
             'no_signals',
@@ -1270,131 +1274,156 @@ BATTERY_VT(
             'abs'
         ]
 
-        for database in databases:
-            if isinstance(database, tuple):
-                database, basename = database
-            else:
-                basename = database
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
 
-            argv = [
-                'cantools',
-                'generate_c_source',
-                'tests/files/dbc/{}.dbc'.format(database)
-            ]
-            if database == 'floating_point_use_float':
-                argv.insert(-1, '--use-float')
+            for database in databases:
+                if isinstance(database, tuple):
+                    database, basename = database
+                else:
+                    basename = database
 
-            database_h = basename + '.h'
-            database_c = basename + '.c'
-            fuzzer_c = basename + '_fuzzer.c'
-            fuzzer_mk = basename + '_fuzzer.mk'
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    f'tests/files/dbc/{database}.dbc',
+                    '-o',
+                    str(tmpdir),
+                ]
+                if database == 'floating_point_use_float':
+                    argv.append('--use-float')
 
-            if os.path.exists(database_h):
-                os.remove(database_h)
+                with patch('sys.argv', argv), warnings.catch_warnings(record=True) as w:
+                    cantools._main()
 
-            if os.path.exists(database_c):
-                os.remove(database_c)
+                    if database == 'floating_point_use_float':
+                        assert str(w[-1].message) == (
+                            "User selected `--use-float`, but database contains "
+                            "signal with data type `double`: \"Message1::Signal1\"")
 
-            if os.path.exists(fuzzer_c):
-                os.remove(fuzzer_c)
+                database_h = basename + '.h'
+                database_c = basename + '.c'
+                fuzzer_c = basename + '_fuzzer.c'
+                fuzzer_mk = basename + '_fuzzer.mk'
 
-            if os.path.exists(fuzzer_mk):
-                os.remove(fuzzer_mk)
-
-            with patch('sys.argv', argv):
-                cantools._main()
-
-            if sys.version_info[0] > 2:
-                self.assert_files_equal(database_h,
+                self.assert_files_equal(tmpdir / database_h,
                                         'tests/files/c_source/' + database_h)
-                self.assert_files_equal(database_c,
+                self.assert_files_equal(tmpdir / database_c,
                                         'tests/files/c_source/' + database_c)
-
-            self.assertFalse(os.path.exists(fuzzer_c))
-            self.assertFalse(os.path.exists(fuzzer_mk))
+                self.assertFalse((tmpdir / fuzzer_c).exists())
+                self.assertFalse((tmpdir / fuzzer_mk).exists())
 
     def test_generate_c_source_no_signal_encode_decode(self):
         databases = [
             'motohawk',
+            'open_actuator'
         ]
 
-        for database in databases:
-            argv = [
-                'cantools',
-                'generate_c_source',
-                '--no-floating-point-numbers',
-                'tests/files/dbc/{}.dbc'.format(database)
-            ]
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
 
-            database_h = database + '.h'
-            database_c = database + '.c'
-            expected_database_h = database + '_no_floating_point_numbers.h'
-            expected_database_c = database + '_no_floating_point_numbers.c'
+            for database in databases:
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    '--no-floating-point-numbers',
+                    f'tests/files/dbc/{database}.dbc',
+                    '-o',
+                    str(tmpdir),
+                ]
 
-            if os.path.exists(database_h):
-                os.remove(database_h)
+                database_h = database + '.h'
+                database_c = database + '.c'
+                expected_database_h = database + '_no_floating_point_numbers.h'
+                expected_database_c = database + '_no_floating_point_numbers.c'
 
-            if os.path.exists(database_c):
-                os.remove(database_c)
+                with patch('sys.argv', argv):
+                    cantools._main()
 
-            with patch('sys.argv', argv):
-                cantools._main()
-
-            if sys.version_info[0] > 2:
                 self.assert_files_equal(
-                    database_h,
+                    tmpdir / database_h,
                     'tests/files/c_source/' + expected_database_h)
                 self.assert_files_equal(
-                    database_c,
+                    tmpdir / database_c,
                     'tests/files/c_source/' + expected_database_c)
 
+    def test_generate_c_source_sender_node_no_signal_encode_decode(self):
+        databases = [
+            'motohawk',
+            'open_actuator'
+        ]
+        nodes = [
+            'PCM1',
+            'Actuator'
+        ]
+
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
+
+            for database, node in zip(databases, nodes):
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    '--no-floating-point-numbers',
+                    '--node', node,
+                    f'tests/files/dbc/{database}.dbc',
+                    '-o',
+                    str(tmpdir),
+                ]
+
+                database_h = database + '.h'
+                database_c = database + '.c'
+                expected_database_h = database + '_sender_node_no_floating_point_numbers.h'
+                expected_database_c = database + '_sender_node_no_floating_point_numbers.c'
+
+                with patch('sys.argv', argv):
+                    cantools._main()
+
+                self.assert_files_equal(tmpdir / database_h,
+                                        'tests/files/c_source/' + expected_database_h)
+                self.assert_files_equal(tmpdir / database_c,
+                                        'tests/files/c_source/' + expected_database_c)
+
     def test_generate_c_source_database_name(self):
         databases = [
             'motohawk',
         ]
 
-        for database in databases:
-            argv = [
-                'cantools',
-                'generate_c_source',
-                '--database-name', 'my_database_name',
-                'tests/files/dbc/{}.dbc'.format(database)
-            ]
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
 
-            database_h = 'my_database_name.h'
-            database_c = 'my_database_name.c'
+            for database in databases:
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    '--database-name', 'my_database_name',
+                    f'tests/files/dbc/{database}.dbc',
+                    '-o',
+                    str(tmpdir),
+                ]
 
-            if os.path.exists(database_h):
-                os.remove(database_h)
+                database_h = 'my_database_name.h'
+                database_c = 'my_database_name.c'
 
-            if os.path.exists(database_c):
-                os.remove(database_c)
+                with patch('sys.argv', argv):
+                    cantools._main()
 
-            with patch('sys.argv', argv):
-                cantools._main()
-
-            if sys.version_info[0] > 2:
-                self.assert_files_equal(database_h,
+                self.assert_files_equal(tmpdir / database_h,
                                         'tests/files/c_source/' + database_h)
-                self.assert_files_equal(database_c,
+                self.assert_files_equal(tmpdir / database_c,
                                         'tests/files/c_source/' + database_c)
 
-    def test_generate_c_source_output_directory(self):
+    def test_generate_c_source_working_directory(self):
         database = 'motohawk'
-        
-        output_directory = 'some_dir'
 
         argv = [
             'cantools',
             'generate_c_source',
-            '--output-directory', output_directory,
-            'tests/files/dbc/{}.dbc'.format(database)
+            f'tests/files/dbc/{database}.dbc'
         ]
 
-        database_h = os.path.join(output_directory, f'{database}.h')
-        database_c = os.path.join(output_directory, f'{database}.c')
-
-        shutil.rmtree(output_directory, ignore_errors=True)
+        database_h = database + '.h'
+        database_c = database + '.c'
 
         with patch('sys.argv', argv):
             cantools._main()
@@ -1404,6 +1433,12 @@ BATTERY_VT(
         self.assert_files_equal(database_c,
                                 'tests/files/c_source/' + os.path.basename(database_c))
 
+        if os.path.exists(database_h):
+            os.remove(database_h)
+
+        if os.path.exists(database_c):
+            os.remove(database_c)
+
     def test_generate_c_source_bit_fields(self):
         databases = [
             'motohawk',
@@ -1411,69 +1446,95 @@ BATTERY_VT(
             'signed'
         ]
 
-        for database in databases:
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
+
+            for database in databases:
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    '--bit-fields',
+                    '--database-name', f'{database}_bit_fields',
+                    f'tests/files/dbc/{database}.dbc',
+                    '-o',
+                    str(tmpdir),
+                ]
+
+                database_h = database + '_bit_fields.h'
+                database_c = database + '_bit_fields.c'
+
+                with patch('sys.argv', argv):
+                    cantools._main()
+
+                self.assert_files_equal(tmpdir / database_h,
+                                        'tests/files/c_source/' + database_h)
+                self.assert_files_equal(tmpdir / database_c,
+                                        'tests/files/c_source/' + database_c)
+
+    def test_generate_c_source_sender_node(self):
+        databases = [
+            'motohawk',
+            'open_actuator'
+        ]
+        nodes = [
+            'PCM1',
+            'Actuator'
+        ]
+
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
+
+            for database, node in zip(databases, nodes):
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    '--node', node,
+                    f'tests/files/dbc/{database}.dbc',
+                    '-o',
+                    str(tmpdir),
+                ]
+
+                database_h = database + '.h'
+                database_c = database + '.c'
+                expected_database_h = database + '_sender_node.h'
+                expected_database_c = database + '_sender_node.c'
+
+                with patch('sys.argv', argv):
+                    cantools._main()
+
+                self.assert_files_equal(tmpdir / database_h,
+                                        'tests/files/c_source/' + expected_database_h)
+                self.assert_files_equal(tmpdir / database_c,
+                                        'tests/files/c_source/' + expected_database_c)
+
+    def test_generate_c_source_generate_fuzzer(self):
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
+
             argv = [
                 'cantools',
                 'generate_c_source',
-                '--bit-fields',
-                '--database-name', '{}_bit_fields'.format(database),
-                'tests/files/dbc/{}.dbc'.format(database)
+                '--generate-fuzzer',
+                'tests/files/dbc/multiplex_2.dbc',
+                '-o',
+                str(tmpdir),
             ]
 
-            database_h = database + '_bit_fields.h'
-            database_c = database + '_bit_fields.c'
-
-            if os.path.exists(database_h):
-                os.remove(database_h)
-
-            if os.path.exists(database_c):
-                os.remove(database_c)
+            database_h = 'multiplex_2.h'
+            database_c = 'multiplex_2.c'
+            fuzzer_c = 'multiplex_2_fuzzer.c'
+            fuzzer_mk = 'multiplex_2_fuzzer.mk'
 
             with patch('sys.argv', argv):
                 cantools._main()
 
-            if sys.version_info[0] > 2:
-                self.assert_files_equal(database_h,
-                                        'tests/files/c_source/' + database_h)
-                self.assert_files_equal(database_c,
-                                        'tests/files/c_source/' + database_c)
-
-    def test_generate_c_source_generate_fuzzer(self):
-        argv = [
-            'cantools',
-            'generate_c_source',
-            '--generate-fuzzer',
-            'tests/files/dbc/multiplex_2.dbc'
-        ]
-
-        database_h = 'multiplex_2.h'
-        database_c = 'multiplex_2.c'
-        fuzzer_c = 'multiplex_2_fuzzer.c'
-        fuzzer_mk = 'multiplex_2_fuzzer.mk'
-
-        if os.path.exists(database_h):
-            os.remove(database_h)
-
-        if os.path.exists(database_c):
-            os.remove(database_c)
-
-        if os.path.exists(fuzzer_c):
-            os.remove(fuzzer_c)
-
-        if os.path.exists(fuzzer_mk):
-            os.remove(fuzzer_mk)
-
-        with patch('sys.argv', argv):
-            cantools._main()
-
-        if sys.version_info[0] > 2:
-            self.assert_files_equal(database_h,
+            self.assert_files_equal(tmpdir / database_h,
                                     'tests/files/c_source/' + database_h)
-            self.assert_files_equal(database_c,
+            self.assert_files_equal(tmpdir / database_c,
                                     'tests/files/c_source/' + database_c)
-            self.assert_files_equal(fuzzer_c,
+            self.assert_files_equal(tmpdir / fuzzer_c,
                                     'tests/files/c_source/' + fuzzer_c)
-            self.assert_files_equal(fuzzer_mk,
+            self.assert_files_equal(tmpdir / fuzzer_mk,
                                     'tests/files/c_source/' + fuzzer_mk)
 
     def test_generate_c_source_sym(self):
@@ -1482,46 +1543,37 @@ BATTERY_VT(
             ('letter-terminated-can-id-6.0', 'letter_terminated_can_id_6_0')
         ]
 
-        for database in databases:
-            if isinstance(database, tuple):
-                database, basename = database
-            else:
-                basename = database
+        with tempfile.TemporaryDirectory() as _tmpdir:
+            tmpdir = Path(_tmpdir)
 
-            argv = [
-                'cantools',
-                'generate_c_source',
-                'tests/files/sym/{}.sym'.format(database)
-            ]
+            for database in databases:
+                if isinstance(database, tuple):
+                    database, basename = database
+                else:
+                    basename = database
 
-            database_h = basename + '.h'
-            database_c = basename + '.c'
-            fuzzer_c = basename + '_fuzzer.c'
-            fuzzer_mk = basename + '_fuzzer.mk'
+                argv = [
+                    'cantools',
+                    'generate_c_source',
+                    f'tests/files/sym/{database}.sym',
+                    '-o',
+                    str(tmpdir),
+                ]
 
-            if os.path.exists(database_h):
-                os.remove(database_h)
+                database_h = basename + '.h'
+                database_c = basename + '.c'
+                fuzzer_c = basename + '_fuzzer.c'
+                fuzzer_mk = basename + '_fuzzer.mk'
 
-            if os.path.exists(database_c):
-                os.remove(database_c)
+                with patch('sys.argv', argv):
+                    cantools._main()
 
-            if os.path.exists(fuzzer_c):
-                os.remove(fuzzer_c)
-
-            if os.path.exists(fuzzer_mk):
-                os.remove(fuzzer_mk)
-
-            with patch('sys.argv', argv):
-                cantools._main()
-
-            if sys.version_info[0] > 2:
-                self.assert_files_equal(database_h,
+                self.assert_files_equal(tmpdir / database_h,
                                         'tests/files/c_source/' + database_h)
-                self.assert_files_equal(database_c,
+                self.assert_files_equal(tmpdir / database_c,
                                         'tests/files/c_source/' + database_c)
-
-            self.assertFalse(os.path.exists(fuzzer_c))
-            self.assertFalse(os.path.exists(fuzzer_mk))
+                self.assertFalse((tmpdir / fuzzer_c).exists())
+                self.assertFalse((tmpdir / fuzzer_mk).exists())
 
 
 if __name__ == '__main__':
