@@ -1,6 +1,5 @@
-import os
-import unittest
 import logging
+import unittest
 
 import cantools
 
@@ -322,20 +321,20 @@ class CanToolsDiagnosticsDatabaseTest(unittest.TestCase):
             "did('A_D_Werte', 0x0040)\n"
             "  data('Voltage', 7, 8, 'big_endian', 0.1, 0.0, 0, 255, 'V', None)\n"
             "  data('Current', 15, 8, 'big_endian', 0.1, 0.0, 0, 255, 'A', None)\n"
-            "  data('Resistance', 23, 16, 'big_endian', 10.0, 0.0, 0, 255, 'Ohm', None)\n"
+            "  data('Resistance', 23, 16, 'big_endian', 10, 0, 0, 255, 'Ohm', None)\n"
             "\n"
             "did('SawTooth', 0x00f4)\n"
-            "  data('ampl', 7, 8, 'big_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
-            "  data('period', 15, 8, 'big_endian', 20.0, 0.0, 0, 255, 'sec', None)\n"
-            "  data('value', 23, 8, 'big_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('ampl', 7, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
+            "  data('period', 15, 8, 'big_endian', 20, 0, 0, 255, 'sec', None)\n"
+            "  data('value', 23, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "\n"
             "did('Sine', 0x00f3)\n"
-            "  data('ampl', 7, 8, 'big_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
-            "  data('period', 15, 8, 'big_endian', 20.0, 0.0, 0, 255, 'sec', None)\n"
-            "  data('value', 23, 8, 'big_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('ampl', 7, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
+            "  data('period', 15, 8, 'big_endian', 20, 0, 0, 255, 'sec', None)\n"
+            "  data('value', 23, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "\n"
             "did('FaultMemory_identified', 0x00f2)\n"
-            "  data('Number', 7, 8, 'big_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('Number', 7, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_1', 15, 16, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('StatusOfDTC_1', 31, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_2', 39, 16, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
@@ -350,7 +349,7 @@ class CanToolsDiagnosticsDatabaseTest(unittest.TestCase):
             "  data('StatusOfDTC_6', 151, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "\n"
             "did('FaultMemory_supported', 0x00f1)\n"
-            "  data('Number', 7, 8, 'big_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('Number', 7, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_1', 15, 16, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('StatusOfDTC_1', 31, 8, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_2', 39, 16, 'big_endian', 1, 0, 0, 255, 'None', None)\n"
@@ -415,20 +414,20 @@ class CanToolsDiagnosticsDatabaseTest(unittest.TestCase):
             "did('A_D_Werte', 0x0040)\n"
             "  data('Voltage', 0, 8, 'little_endian', 0.1, 0.0, 0, 255, 'V', None)\n"
             "  data('Current', 8, 8, 'little_endian', 0.1, 0.0, 0, 255, 'A', None)\n"
-            "  data('Resistance', 16, 16, 'little_endian', 10.0, 0.0, 0, 255, 'Ohm', None)\n"
+            "  data('Resistance', 16, 16, 'little_endian', 10, 0, 0, 255, 'Ohm', None)\n"
             "\n"
             "did('SawTooth', 0x00f4)\n"
-            "  data('ampl', 0, 8, 'little_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
-            "  data('period', 8, 8, 'little_endian', 20.0, 0.0, 0, 255, 'sec', None)\n"
-            "  data('value', 16, 8, 'little_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('ampl', 0, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
+            "  data('period', 8, 8, 'little_endian', 20, 0, 0, 255, 'sec', None)\n"
+            "  data('value', 16, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "\n"
             "did('Sine', 0x00f3)\n"
-            "  data('ampl', 0, 8, 'little_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
-            "  data('period', 8, 8, 'little_endian', 20.0, 0.0, 0, 255, 'sec', None)\n"
-            "  data('value', 16, 8, 'little_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('ampl', 0, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
+            "  data('period', 8, 8, 'little_endian', 20, 0, 0, 255, 'sec', None)\n"
+            "  data('value', 16, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "\n"
             "did('FaultMemory_identified', 0x00f2)\n"
-            "  data('Number', 0, 8, 'little_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('Number', 0, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_1', 8, 16, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('StatusOfDTC_1', 24, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_2', 32, 16, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
@@ -443,7 +442,7 @@ class CanToolsDiagnosticsDatabaseTest(unittest.TestCase):
             "  data('StatusOfDTC_6', 144, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "\n"
             "did('FaultMemory_supported', 0x00f1)\n"
-            "  data('Number', 0, 8, 'little_endian', 1.0, 0.0, 0, 255, 'None', None)\n"
+            "  data('Number', 0, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_1', 8, 16, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('StatusOfDTC_1', 24, 8, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
             "  data('DTC_2', 32, 16, 'little_endian', 1, 0, 0, 255, 'None', None)\n"
@@ -491,6 +490,10 @@ class CanToolsDiagnosticsDatabaseTest(unittest.TestCase):
 
         self.assertEqual(str(pe.exception), "Unknown byte order code: 4321")
 
+    def test_datarefs(self):
+        db = cantools.db.load_file('tests/files/cdd/example-diddatarefs.cdd', encoding = 'iso-8859-1')
+        self.assertEqual(len(db.dids[-1].datas), 2)
+
 
 # This file is not '__main__' when executed via 'python setup.py3
 # test'.
