@@ -1,16 +1,6 @@
 import unittest
-import traceback
+from unittest.mock import patch
 
-try:
-    from unittest.mock import Mock
-    from unittest.mock import patch
-    from unittest.mock import call
-except ImportError:
-    from mock import Mock
-    from mock import patch
-    from mock import call
-
-import can
 import cantools.subparsers.list as list_module
 
 try:
@@ -18,15 +8,16 @@ try:
 except ImportError:
     from io import StringIO
 
-class Args(object):
+class Args:
 
-    def __init__(self, database):
+    def __init__(self, input_file_name):
         self.exclude_normal = False
         self.exclude_extended = False
         self.print_all = False
         self.no_strict = False
+        self.skip_format_specifics = False
         self.prune = True
-        self.file = (database, )
+        self.input_file_name = (input_file_name, )
         self.print_buses = False
         self.print_nodes = False
         self.items = []
@@ -67,7 +58,6 @@ ExampleMessage:
   Size: 8 bytes
   Is extended frame: False
   Is CAN-FD frame: False
-  Is secured: False
   Signal tree:
 
     -- {root}
@@ -77,37 +67,39 @@ ExampleMessage:
 
   Signal details:
     Enable:
-      Type: Integer
+      Internal type: Integer
       Start bit: 7
       Length: 1 bits
+      Byte order: big_endian
       Unit: -
       Is signed: False
       Named values:
         0: Disabled
         1: Enabled
     AverageRadius:
-      Type: Integer
+      Internal type: Integer
       Start bit: 6
       Length: 6 bits
+      Byte order: big_endian
       Unit: m
       Is signed: False
-      Minimum: 0
-      Maximum: 5
-      Offset: 0
-      Scaling factor: 0.1
+      Minimum: 0 m
+      Maximum: 5 m
+      Offset: 0 m
+      Scaling factor: 0.1 m
     Temperature:
       Receiving ECUs: FOO, PCM1
-      Type: Integer
+      Internal type: Integer
       Start bit: 0
       Length: 12 bits
+      Byte order: big_endian
       Unit: degK
       Is signed: True
-      Minimum: 229.52
-      Maximum: 270.47
-      Offset: 250
-      Scaling factor: 0.01
+      Minimum: 229.52 degK
+      Maximum: 270.47 degK
+      Offset: 250 degK
+      Scaling factor: 0.01 degK
 """
-
             actual_output = stdout.getvalue()
             self.assertEqual(actual_output, expected_output)
 
@@ -164,7 +156,8 @@ Passenger:
             expected_output = """\
 DJ:
 Dancer:
-  Comment[FOR-ALL]: Rythm is a Dancer!
+  Comment[FOR-ALL]: Rhythm is a Dancer!
+Guard:
 """
 
             actual_output = stdout.getvalue()
@@ -172,7 +165,7 @@ Dancer:
 
         # Prepare mocks.
         args = Args('tests/files/arxml/system-4.2.arxml')
-        args.items = ["Message2"]
+        args.items = ['Message2']
 
         stdout = StringIO()
         with patch('sys.stdout', stdout):
@@ -189,6 +182,7 @@ Message2:
   Is extended frame: True
   Is CAN-FD frame: True
   Cycle time: 200 ms
+  Is network management frame: False
   Is secured: False
   Signal tree:
 
@@ -200,25 +194,26 @@ Message2:
   Signal details:
     signal3:
       Receiving ECUs: DJ
-      Type: Integer
+      Internal type: Integer
       Start bit: 6
       Length: 2 bits
+      Byte order: little_endian
       Is signed: False
     signal2:
       Comment[FOR-ALL]: Signal comment!
       Receiving ECUs: DJ
-      Type: Integer
+      Internal type: Integer
       Start bit: 18
       Length: 11 bits
+      Byte order: little_endian
       Is signed: True
     signal4:
       Receiving ECUs: DJ
-      Type: Integer
+      Internal type: Integer
       Start bit: 30
       Length: 4 bits
+      Byte order: little_endian
       Is signed: False
-      Minimum: 0
-      Maximum: 3
       Named values:
         1: one
           Comment[EN]: One Comment
@@ -229,6 +224,44 @@ Message2:
             actual_output = stdout.getvalue()
             self.assertEqual(actual_output, expected_output)
 
+        args = Args('tests/files/arxml/system-4.2.arxml')
+        args.items = ['AlarmStatus']
+
+        stdout = StringIO()
+        with patch('sys.stdout', stdout):
+            # Run the main function of the subparser
+            list_module._do_list(args)
+
+            # check make sure it behaves as expected
+            expected_output = """\
+AlarmStatus:
+  Bus: Cluster0
+  Sending ECUs: Guard
+  Frame ID: 0x3e9 (1001)
+  Size: 1 bytes
+  Is extended frame: False
+  Is CAN-FD frame: False
+  Is network management frame: True
+  Is secured: False
+  Signal tree:
+
+    -- {root}
+       +-- FireAlarm
+
+  Signal details:
+    FireAlarm:
+      Receiving ECUs: DJ, Dancer
+      Internal type: Integer
+      Start bit: 0
+      Length: 1 bits
+      Byte order: little_endian
+      Initial value: 0
+      Is signed: False
+"""
+
+            actual_output = stdout.getvalue()
+            self.assertEqual(actual_output, expected_output)
+
         args = Args('tests/files/arxml/system-4.2.arxml')
         args.exclude_normal = True
 
@@ -253,9 +286,11 @@ Message2:
 
             # check make sure it behaves as expected
             expected_output = """\
+AlarmStatus
 Message1
 Message3
 Message4
+MessageWithoutPDU
 MultiplexedMessage
 OneToContainThemAll
 """
@@ -264,7 +299,7 @@ OneToContainThemAll
             self.assertEqual(actual_output, expected_output)
 
         args = Args('tests/files/arxml/system-4.2.arxml')
-        args.items = [ "IAmAGhost" ]
+        args.items = [ 'IAmAGhost' ]
 
         stdout = StringIO()
         with patch('sys.stdout', stdout):
@@ -280,7 +315,7 @@ No message named "IAmAGhost" has been found in input file.
             self.assertEqual(actual_output, expected_output)
 
         args = Args('tests/files/arxml/system-4.2.arxml')
-        args.items = [ "Message1" ]
+        args.items = [ 'Message1' ]
 
         stdout = StringIO()
         with patch('sys.stdout', stdout):
@@ -298,8 +333,11 @@ Message1:
   Size: 9 bytes
   Is extended frame: False
   Is CAN-FD frame: True
-  End-to-end category: Profile2
-  Data IDs: [123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138]
+  Is network management frame: False
+  End-to-end properties:
+    Category: Profile2
+    Data IDs: [123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138]
+    Protected size: 9 bytes
   Is secured: False
   Signal tree:
 
@@ -313,28 +351,31 @@ Message1:
   Signal details:
     message1_SeqCounter:
       Receiving ECUs: Dancer
-      Type: Integer
+      Internal type: Integer
       Start bit: 0
       Length: 16 bits
+      Byte order: little_endian
       Is signed: False
     message1_CRC:
       Receiving ECUs: Dancer
-      Type: Integer
+      Internal type: Integer
       Start bit: 16
       Length: 16 bits
+      Byte order: little_endian
       Is signed: False
     signal6:
       Receiving ECUs: Dancer
-      Type: Integer
+      Internal type: Integer
       Start bit: 32
       Length: 1 bits
+      Byte order: little_endian
       Unit: wp
-      Initial value: False
+      Initial value: zero
       Is signed: False
-      Minimum: 0.0
-      Maximum: 0.1
-      Offset: 0.0
-      Scaling factor: 0.1
+      Minimum: 0.0 wp
+      Maximum: 0.1 wp
+      Offset: 0.0 wp
+      Scaling factor: 0.1 wp
       Named values:
         0: zero
           Comment[EN]: Nothing
@@ -343,21 +384,98 @@ Message1:
       Comment[EN]: Signal comment!
       Comment[DE]: Signalkommentar!
       Receiving ECUs: Dancer
-      Type: Integer
+      Internal type: Integer
       Start bit: 36
       Length: 3 bits
+      Byte order: big_endian
       Unit: m
-      Initial value: 25.0 m
+      Initial value: 25 m
       Is signed: False
-      Minimum: 0.0
-      Maximum: 20.0
-      Offset: 0.0
-      Scaling factor: 5.0
+      Minimum: 0.0 m
+      Maximum: 20.0 m
+      Offset: 0 m
+      Scaling factor: 5 m
     signal5:
       Receiving ECUs: Dancer
-      Type: Float
+      Internal type: Float
       Start bit: 40
       Length: 32 bits
+      Byte order: little_endian
+      Is signed: False
+"""
+
+            actual_output = stdout.getvalue()
+            self.assertEqual(actual_output, expected_output)
+
+        args = Args('tests/files/arxml/system-4.2.arxml')
+        args.items = [ "Message3" ]
+
+        stdout = StringIO()
+        with patch('sys.stdout', stdout):
+            # Run the main function of the subparser
+            list_module._do_list(args)
+
+            # check make sure it behaves as expected
+            expected_output = """\
+Message3:
+  Bus: Cluster0
+  Sending ECUs: Dancer
+  Frame ID: 0x64 (100)
+  Size: 6 bytes
+  Is extended frame: False
+  Is CAN-FD frame: False
+  Is network management frame: False
+  End-to-end properties:
+    Category: Profile5
+    Data IDs: [321]
+    Protected size: 4 bytes
+  Is secured: True
+  Security properties:
+    Authentication algorithm: KnockKnock
+    Freshness algorithm: SmellyCheese
+    Data ID: 1337
+    Authentication transmit bits: 10
+    Freshness counter size: 32 bits
+    Freshness counter transmit size: 6 bits
+    Secured size: 4 bytes
+  Signal tree:
+
+    -- {root}
+       +-- message3_CRC
+       +-- message3_SeqCounter
+       +-- Message3_Freshness
+       +-- Message3_Authenticator
+
+  Signal details:
+    message3_CRC:
+      Receiving ECUs: DJ
+      Internal type: Integer
+      Start bit: 0
+      Length: 8 bits
+      Byte order: little_endian
+      Is signed: False
+    message3_SeqCounter:
+      Receiving ECUs: DJ
+      Internal type: Integer
+      Start bit: 8
+      Length: 4 bits
+      Byte order: little_endian
+      Is signed: False
+    Message3_Freshness:
+      Comment[FOR-ALL]: Truncated freshness value for 'Message3'
+      Receiving ECUs: DJ
+      Internal type: Integer
+      Start bit: 39
+      Length: 6 bits
+      Byte order: big_endian
+      Is signed: False
+    Message3_Authenticator:
+      Comment[FOR-ALL]: Truncated authenticator value for 'Message3'
+      Receiving ECUs: DJ
+      Internal type: Integer
+      Start bit: 33
+      Length: 10 bits
+      Byte order: big_endian
       Is signed: False
 """
 
@@ -397,7 +515,6 @@ Cluster0:
             list_module._do_list(args)
 
             # check make sure it behaves as expected
-            expected_output = ""
             expected_output = """\
 Message1:
   Bus: Bus
@@ -406,7 +523,6 @@ Message1:
   Size: 5 bytes
   Is extended frame: False
   Is CAN-FD frame: False
-  Is secured: False
   Signal tree:
 
     -- {root}
@@ -415,15 +531,17 @@ Message1:
 
   Signal details:
     Signal1:
-      Type: Integer
+      Internal type: Integer
       Start bit: 0
       Length: 1 bits
+      Byte order: little_endian
       Is signed: False
     Signal2:
       Receiving ECUs: Node2, Node3
-      Type: Float
+      Internal type: Float
       Start bit: 8
       Length: 32 bits
+      Byte order: little_endian
       Is signed: False
       Named values:
         0: label1
@@ -437,7 +555,6 @@ Message2:
   Is extended frame: False
   Is CAN-FD frame: False
   Cycle time: 100 ms
-  Is secured: False
   Signal tree:
 
     -- {root}
@@ -455,62 +572,70 @@ Message2:
 
   Signal details:
     Signal1:
-      Type: Integer
+      Internal type: Integer
       Selector signal: Mux1
       Selector values: 0
       Start bit: 0
       Length: 8 bits
+      Byte order: little_endian
       Is signed: False
     Signal3:
-      Type: Integer
+      Internal type: Integer
       Selector signal: Mux1
       Selector values: 1
       Start bit: 0
       Length: 8 bits
+      Byte order: little_endian
       Is signed: False
     Signal2:
-      Type: Integer
+      Internal type: Integer
       Selector signal: Mux1
       Selector values: 0
       Start bit: 8
       Length: 8 bits
+      Byte order: little_endian
       Is signed: False
     Signal4:
-      Type: Integer
+      Internal type: Integer
       Selector signal: Mux1
       Selector values: 1
       Start bit: 8
       Length: 8 bits
+      Byte order: little_endian
       Is signed: False
     Mux1:
-      Type: Multiplex Selector
+      Internal type: Multiplex Selector
       Start bit: 16
       Length: 2 bits
+      Byte order: little_endian
       Is signed: False
     Mux2:
-      Type: Multiplex Selector
+      Internal type: Multiplex Selector
       Start bit: 18
       Length: 1 bits
+      Byte order: little_endian
       Is signed: False
     Signal5:
-      Type: Integer
+      Internal type: Integer
       Selector signal: Mux2
       Selector values: 0
       Start bit: 19
       Length: 1 bits
+      Byte order: little_endian
       Is signed: False
     Signal6:
       Comment[None]: Note signal 6.
       Receiving ECUs: Node1
-      Type: Integer
+      Internal type: Integer
       Start bit: 20
       Length: 12 bits
+      Byte order: little_endian
       Unit: Cel
       Is signed: True
-      Minimum: 0
-      Maximum: 100
-      Offset: -40
-      Scaling factor: 0.05
+      Minimum: 0 Cel
+      Maximum: 100 Cel
+      Offset: -40 Cel
+      Scaling factor: 0.05 Cel
       Named values:
         0: init
 Message4:
@@ -519,7 +644,6 @@ Message4:
   Size: 5 bytes
   Is extended frame: False
   Is CAN-FD frame: False
-  Is secured: False
   Signal tree:
 
     -- {root}
@@ -528,14 +652,16 @@ Message4:
 
   Signal details:
     Signal1:
-      Type: Integer
+      Internal type: Integer
       Start bit: 7
       Length: 1 bits
+      Byte order: big_endian
       Is signed: False
     Signal2:
-      Type: Integer
+      Internal type: Integer
       Start bit: 8
       Length: 12 bits
+      Byte order: big_endian
       Is signed: False
 """
 
@@ -560,7 +686,6 @@ Message3:
   Size: 8 bytes
   Is extended frame: True
   Is CAN-FD frame: False
-  Is secured: False
   Signal tree:
 
     -- {root}
@@ -568,9 +693,10 @@ Message3:
 
   Signal details:
     Signal1:
-      Type: Float
+      Internal type: Float
       Start bit: 0
       Length: 64 bits
+      Byte order: little_endian
       Is signed: False
 """
 
